/*
Tool: 					Distance buffer for randomization
Date created: 			january 8, 2022
Created by:             
What it does: 			This dofile presents an example of village randomization 
						based on the distance each one has from the other.
                        						
Version of software: 	17.0
*/

clear all
cd "C:\Users\Soporte\Dropbox\Research Assistant\TOOLKIT\Distance buffer for randomization\"

*======================================================================
* 1. Calculation of the distance between the villages two by two 
*======================================================================

* We open the database with the longitude and latitude information of each Village.
use "example_data.dta"

rename commune commune0
rename village village0
rename lon lon0
rename lat lat0

cross using "example_data.dta" /* command cross forms every pairwise combination of the data in memory with the data in filename */ 

*Install geodist command
*ssc install geodist

geodist lat0 lon0 lat lon, gen(d) /* The geodist command calculates the distance between villages. Option gen creates a variable with the calculated distances */

* We Keep only villages on at least 10 km each others
keep if d >=10 /* Here we can choose the distance we want */ 

* Canceling duplication village observations
sort village
quietly by village : gen dup = cond(_N==1,0,_n)
drop if dup>1
drop commune0 village0 lon0 lat0 dup
sort commune
* We save the database with the calculated distances.
save "example_data_with_distance.dta", replace /*example_data_distance2*/


/* ================================================================================
  2. Creation databases by communes
  We can create databases for the geographic aggregates that we need. In this case 
  there are three communes: Abomey Calavi, Cotonou and Parakou.
* ================================================================================ */

* ---------------------- For Abomey-Calavi
use "example_data_with_distance.dta"
keep if commune=="ABOMEY-CALAVI"
save "ABOMEY-CALAVI.dta", replace 

* ---------------------- For COTONOU 
clear
use "example_data_with_distance.dta" 
keep if commune=="COTONOU"
save "COTONOU.dta", replace 

* ---------------------- For PARAKOU
clear
use "example_data_with_distance.dta" 
keep if commune=="PARAKOU"
save "PARAKOU.dta", replace 


/*======================================================================================
 3. Randomization of villages by commune. (Abomey Calavi, Cotonou and Parakou)
 In this case, we make up three groups (two treatment groups and a control group) for 
 each commune. Each group contains 14 randomly selected villages. 
 ====================================================================================== */

* ------------------------ For Abomey-Calavi
use "ABOMEY-CALAVI.dta"

sort village
set seed 987654321 /* We set a seed to replicate the randomization */
gen random =  runiform()
sort random 
gen group = 1 if _n <= 14
replace group = 2 if _n > 14 & _n <= 28
replace group = 3 if _n > 28 & _n <= 42
drop if group ==. 
drop random

save "ABOMEY-CALAVI_Groups.dta", replace



* ------------------------ For COTONOU
use "COTONOU.dta"

sort village
set seed 987654321 /* We set a seed to replicate the randomization */
gen random =  runiform()
sort random 
gen group = 1 if _n <= 14
replace group = 2 if _n > 14 & _n <= 28
replace group = 3 if _n > 28 & _n <= 42
drop if group ==. 
drop random

save "COTONOU_Groups.dta", replace



* ------------------------ For PARAKOU
use "PARAKOU.dta"

sort village
set seed 987654321 /* We set a seed to replicate the randomization */
gen random =  runiform()
sort random 
gen group = 1 if _n <= 14
replace group = 2 if _n > 14 & _n <= 28
replace group = 3 if _n > 28 & _n <= 42
drop if group ==. 
drop random

save "PARAKOU_Groups.dta", replace


* --------------------------------- END --------------------------------------- *
